@@ -151,9 +151,10 @@ def construct_alert(frm, channel, msg, elapsed=None):
     alert_title = frm + "@" + channel + ":"
     message = msg
     if elapsed:
-        message += " (" + str(round(seconds_listen_channel - elapsed)) + "s left)"
+        tim = str(int(seconds_listen_channel - elapsed))
+        message += " (" + tim + "s left)"
     if debug:
-        the_printer("",message)
+        the_printer("","[THE-MESSAGE]: " + message)
     message = trim_leading_dashes(message)
     alert = trim_leading_dashes(alert_title)
     return alert, message
